function varargout = instantGroup(varargin)
% INSTANTGROUP M-file for instantGroup.fig
%
% See my Instant Color Radio Group Demo documentation 
% (InstantGroupDemo.doc) for more information.
%
% Created by Dr. C. S. Tritt
% Last revsied: 1/24/07 (version 1.0)
%
% See also: GUIDE, GUIDATA, GUIHANDLES

% Copyright 2002-2003 The MathWorks, Inc.

% Edit the above text to modify the response to help instantGroup

% Last Modified by GUIDE v2.5 23-Jan-2007 19:16:23

% Begin initialization code - DO NOT EDIT
gui_Singleton = 1;
gui_State = struct('gui_Name',       mfilename, ...
                   'gui_Singleton',  gui_Singleton, ...
                   'gui_OpeningFcn', @instantGroup_OpeningFcn, ...
                   'gui_OutputFcn',  @instantGroup_OutputFcn, ...
                   'gui_LayoutFcn',  [] , ...
                   'gui_Callback',   []);
if nargin && ischar(varargin{1})
    gui_State.gui_Callback = str2func(varargin{1});
end

if nargout
    [varargout{1:nargout}] = gui_mainfcn(gui_State, varargin{:});
else
    gui_mainfcn(gui_State, varargin{:});
end
% End initialization code - DO NOT EDIT

% --- Executes just before instantGroup is made visible.
function instantGroup_OpeningFcn(hObject, eventdata, handles, varargin)
% This function has no output args, see OutputFcn.
% hObject    handle to figure
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
% varargin   command line arguments to instantGroup (see VARARGIN)

% Choose default command line output for instantGroup
handles.output = hObject;

% Update handles structure
guidata(hObject, handles);

% UIWAIT makes instantGroup wait for user response (see UIRESUME)
% uiwait(handles.figure1);

% --- Outputs from this function are returned to the command line.
function varargout = instantGroup_OutputFcn(hObject, eventdata, handles) 
% varargout  cell array for returning output args (see VARARGOUT);
% hObject    handle to figure
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Get default command line output from handles structure
varargout{1} = handles.output;

% --------------------------------------------------------------------
function colorGroup_SelectionChangeFcn(hObject, eventdata, handles)
% hObject    handle to colorGroup (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Dr. Tritt's Comments...
% The group tag is used to generate the name of the ChangeFcn callback.
% The hObject passed to this callback is the newly selected button.

switch get(hObject,'Tag')
   case 'redRadio'
      set(handles.colorPanel, 'backgroundColor', [1 0 0]);
   case 'greenRadio'
      set(handles.colorPanel, 'backgroundColor', [0 0.7 0]);
   case 'blueRadio'
      set(handles.colorPanel, 'backgroundColor', [0 0 1]);        
end